import React, { useState, useEffect, useImperativeHandle } from 'react'
import { Space, Table, Modal, message } from 'antd'
import DatasourceData from '../component/DatasourceData'
import {getDataSourceList, delDataSource} from '../services'
import { ExclamationCircleOutlined } from '@ant-design/icons'

const { confirm } = Modal

export default function DatasourceManage({onRef}) {
  // 查看数据源弹窗是否可可视
  const [dataModalVisible, setDataModalVisible] = useState(false)

  // 初始化数据源列表数据 constructor
  const [dataSourceList, setDataSourceList] = useState([])

  // 表格Loading状态
  const [dataLoading, setDataLoading] = useState(false)

  // 获取列表数据
  const fetchDataSourceList = async () => {
    setDataLoading(true)
    const { data } = await getDataSourceList()
    if (data.code === 200) {
      const list = data.data.items.map(item => {
        return {
          key: item.id,
          datasource_name: item.datasource_name,
          datasource: item.datasource,
          tag: item.tag,
          comments: item.comments,
          create_time: item.create_time,
          update_time: item.update_time,
        }
      })
      setDataSourceList(list)
    }
    setDataLoading(false)
  }

  // 暴露更新列表方法
  useImperativeHandle(onRef, () => {
    return {
      updateSourceList: fetchDataSourceList
    }
  })

  // 删除确认
  const DeleteConfirm = (key) => {
    confirm({
      title: '是否要删除该数据源?',
      icon: <ExclamationCircleOutlined />,
      okText: '确认删除',
      okType: 'danger',
      cancelText: '取消',
      onOk: async () => {
        const { data } = await delDataSource(key)
        if (data.code === 200) {
          message.success('删除成功')
          fetchDataSourceList()
        } else {
          message.success('删除失败')
        }
      },
      onCancel() {
        message.info('取消删除')
      }
    })
  }

  // componentDidMount
  useEffect(() => {
    fetchDataSourceList()
  }, []);

  // 格式化事件
  const formatTime = time => {
    const date = new Date(Number(time) * 1000)
    const YY = date.getFullYear()
    const MM =
      date.getMonth() + 1 < 10
        ? '0' + (date.getMonth() + 1)
        : date.getMonth() + 1
    const DD = date.getDate() < 10 ? '0' + date.getDate() : date.getDate()
    const hh = date.getHours() < 10 ? '0' + date.getHours() : date.getHours()
    const mm =
      date.getMinutes() < 10 ? '0' + date.getMinutes() : date.getMinutes()
    const ss =
      date.getSeconds() < 10 ? '0' + date.getSeconds() : date.getSeconds()
    return YY + '-' + MM + '-' + DD + ' ' + hh + ':' + mm + ':' + ss
  }
  // 查看数据
  const checkData = () => {
    setDataModalVisible(true)
    console.log('查看数据源')
  }
  // 编辑数据
  const editData = () => {
    console.log('编辑数据源')
  }
  // 表格项
  const columns = [
    {
      title: '数据源名称',
      dataIndex: 'datasource_name',
      key: 'datasource_name',
    },
    {
      title: '数据源类型',
      dataIndex: 'datasource',
      key: 'datasource',
    },
    {
      title: '标签',
      dataIndex: 'tag',
      key: 'tag',
      render: text => <span style={{ color: '#1881DA' }}>{text}</span>,
    },
    {
      title: '详情',
      key: 'comments',
      dataIndex: 'comments',
    },
    {
      title: '创建时间',
      key: 'create_time',
      dataIndex: 'create_time',
      render: time => formatTime(time),
    },
    {
      title: '更新时间',
      key: 'update_time',
      dataIndex: 'update_time',
      render: time => formatTime(time),
    },
    {
      title: '操作',
      key: 'operation',
      render: (_, record) => (
        <Space size="middle">
          <a href="/#" onClick={checkData} style={{ color: '#1881DA' }}>
            查看
          </a>
          <a href="/#" onClick={editData} style={{ color: '#1881DA' }}>
            编辑
          </a>
          <a href="/#" onClick={() => {
            DeleteConfirm(record.key)
          }} style={{ color: '#1881DA' }}>
            删除
          </a>
        </Space>
      ),
    },
  ]
  // 查看数据源弹窗取消
  const handledataModalCancel = () => {
    setDataModalVisible(false)
  }

  // 查看数据源弹窗数据
  const dataModal = (
    <Modal
      title="数据表预览"
      visible={dataModalVisible}
      onCancel={handledataModalCancel}
      footer={null}
      width={800}
      bodyStyle={{ paddingTop: 0 }}>
      <DatasourceData />
    </Modal>
  )

  // 最终渲染
  return (
    <>
      <Table columns={columns} dataSource={dataSourceList} bordered loading={dataLoading} /> {dataModal}
    </>
  )
}
